package com.goldenwater.slaj.stan.service;

import java.util.List;
import com.goldenwater.slaj.stan.domain.ObjPuno;

public interface IObjPunoService {
    ObjPuno selectObjPunoByGuid(String guid);
    List<ObjPuno> selectObjPunoList(ObjPuno entity);
    int insertObjPuno(ObjPuno entity);
    int updateObjPuno(ObjPuno entity);
    int deleteObjPunoByGuid(String guid);
    int deleteObjPunoByGuids(String[] guids);
}
